@@ -36,7 +36,7 @@ describe 'glance class' do
         container_format => 'bare',
         disk_format      => 'qcow2',
         is_public        => 'yes',
-        source           => 'http://download.cirros-cloud.net/0.3.1/cirros-0.3.1-x86_64-disk.img',
+        source           => 'http://download.cirros-cloud.net/0.3.5/cirros-0.3.5-x86_64-disk.img',
         min_ram          => '64',
         min_disk         => '1024',
         properties       => { 'icanhaz' => 'cheezburger' },
@@ -51,7 +51,7 @@ describe 'glance class' do
 
     describe 'glance images' do
       it 'should create a glance image with proper attributes' do
-        glance_env_opts = '--os-username glance --os-password a_big_secret --os-tenant-name services --os-auth-url http://127.0.0.1:5000/v2.0'
+        glance_env_opts = '--os-identity-api-version 3 --os-username glance --os-password a_big_secret --os-project-name services --os-user-domain-name Default --os-project-domain-name Default --os-auth-url http://127.0.0.1:5000/v3'
         shell("openstack #{glance_env_opts} image list") do |r|
           expect(r.stdout).to match(/test_image/)
         end
