@@ -32,6 +32,7 @@ describe 'glance::api' do
       :scrub_time               => '<SERVICE DEFAULT>',
       :default_store            => false,
       :image_cache_dir          => '/var/lib/glance/image-cache',
+      :image_member_quota       => '<SERVICE DEFAULT>',
       :image_cache_stall_time   => '<SERVICE DEFAULT>',
       :image_cache_max_size     => '<SERVICE DEFAULT>',
       :os_region_name           => 'RegionOne',
@@ -69,6 +70,7 @@ describe 'glance::api' do
         :delayed_delete           => 'true',
         :scrub_time               => '10',
         :image_cache_dir          => '/tmp/glance',
+        :image_member_quota       => '128',
         :image_cache_stall_time   => '10',
         :image_cache_max_size     => '10737418240',
         :os_region_name           => 'RegionOne2',
@@ -126,6 +128,7 @@ describe 'glance::api' do
             'delayed_delete',
             'scrub_time',
             'image_cache_dir',
+            'image_member_quota',
             'enable_v1_api',
             'enable_v2_api',
             'limit_param_default',
@@ -384,6 +387,21 @@ describe 'glance::api' do
       )}
 
     end
+
+    describe 'with barbican parameters' do
+      let :params do
+        default_params.merge!({
+          :keymgr_backend             => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
+          :keymgr_encryption_api_url  => 'https://localhost:9311/v1',
+          :keymgr_encryption_auth_url => 'https://localhost:5000/v3',
+        })
+      end
+      it 'should set keymgr parameters' do
+        is_expected.to contain_glance_api_config('key_manager/backend').with_value('castellan.key_manager.barbican_key_manager.BarbicanKeyManager')
+        is_expected.to contain_glance_api_config('barbican/barbican_endpoint').with_value('https://localhost:9311/v1')
+        is_expected.to contain_glance_api_config('barbican/auth_endpoint').with_value('https://localhost:5000/v3')
+      end
+    end
   end
 
   shared_examples_for 'glance::api Debian' do
