@@ -24,6 +24,7 @@ describe 'glance::registry::logging' do
      :instance_uuid_format => '[instance: %(uuid)s] ',
      :log_date_format => '%Y-%m-%d %H:%M:%S',
      :use_syslog => true,
+     :use_json => true,
      :use_stderr => false,
      :log_facility => 'LOG_FOO',
      :log_dir => '/var/log',
@@ -58,6 +59,7 @@ describe 'glance::registry::logging' do
     it 'configures glance logging settings with default values' do
       is_expected.to contain_oslo__log('glance_registry_config').with(
         :use_syslog => '<SERVICE DEFAULT>',
+        :use_json   => '<SERVICE DEFAULT>',
         :use_stderr => '<SERVICE DEFAULT>',
         :log_dir    => '/var/log/glance',
         :log_file   => '/var/log/glance/registry.log',
@@ -70,6 +72,7 @@ describe 'glance::registry::logging' do
     it 'configures glance logging settings with non-default values' do
       is_expected.to contain_oslo__log('glance_registry_config').with(
         :use_syslog          => true,
+        :use_json            => true,
         :use_stderr          => false,
         :syslog_log_facility => 'LOG_FOO',
         :log_dir             => '/var/log',
